#
# spec file for package python-parver
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-parver
Version:        0.4
Release:        1.4
Summary:        Module to parse and manipulate version numbers
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/RazerM/parver
Source:         https://files.pythonhosted.org/packages/source/p/parver/parver-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Arpeggio >= 1.7
Requires:       python-attrs >= 19.2
Requires:       python-typing_extensions
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Arpeggio >= 1.7}
BuildRequires:  %{python_module attrs >= 19.2}
BuildRequires:  %{python_module hypothesis >= 3.56}
BuildRequires:  %{python_module pretend >= 1.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing_extensions}
# /SECTION
%python_subpackages

%description
parver allows parsing and manipulation of `PEP 440`_ version numbers.

%prep
%autosetup -p1 -n parver-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -q

%files %{python_files}
%license LICENSE
%doc README*
%{python_sitelib}/parver*

%changelog
* Mon Mar 20 2023 pgajdos@suse.com
- version update to 0.4
  Added
    Type hints.
  Removed
    Support for Python 2.7, 3.5, and 3.6.
    __version__, __author__, and __email__ attributes from parver
    module. Use :mod:`importlib.metadata` instead.
* Wed Dec  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Skip build for python 2 to fix build on Leap
  * hypothesis is not python 2 compatible anymore, so either no
    tests or no build with python2.
* Fri Jan 22 2021 Markéta Machová <mmachova@suse.com>
- update to 0.3.1
  * Grammar is parsed when first used to improve import time.
  * The minimum attrs version is now 19.2.
  * Errors raised for keyword-only argument errors on Python 3 did
    not have the right error message.
* Fri Mar  6 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.3.0
  * Version.truncate method to remove trailing zeros from the release segment
  * Version.bump_epoch method.
  * Version now validates each item in the release sequence.
  * Add by keyword argument to bump_pre, bump_post, and bump_dev methods
  * The Version constructor now uses an empty string to represent an implicit
    zero instead of None
  * Version.clear is no longer necessary.
* Tue Feb 12 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Feb 12 2019 John Vandenberg <jayvdb@gmail.com>
- Activate Python 2 support
- Activate %%check
- Use %%license
- Remove unnecessar build dependency on python-devel
- Remove inappropriate Suggests for build related packages
- Add minimum versions for all dependencies
* Sun Jan 20 2019 Niels Abspoel <aboe76@gmail.com>
- Update to parver-0.2.1
* Sat Dec  8 2018 John Vandenberg <jayvdb@gmail.com>
- Update to parver-0.2.0
* Thu Jul  5 2018 aboe76@gmail.com
- Initial package python-parver
